@@ -508,8 +508,9 @@ class AssessedRanges:
             palette = CLIMATE_MODEL_PALETTE
 
         box_plot_df = self._get_box_plot_df(metric, model_results)
-        unit = box_plot_df["unit"].unique().tolist()[0]
+        unit = box_plot_df["unit"].unique().tolist()
         assert len(unit) == 1, unit
+        unit = unit[0]
 
         if box_only:
             box_ax = axs
@@ -526,26 +527,28 @@ class AssessedRanges:
         xlim = box_ax.get_xlim()
 
         if box_only:
-            box_ax.set_ylabel(unit[0])
+            box_ax.set_ylabel(unit)
             box_ax.set_title(metric)
             box_ax.grid(axis="y")
         else:
-            box_ax.set_xlabel(unit[0])
+            box_ax.set_xlabel(unit)
             box_ax.set_title("")
             box_ax.grid(axis="x")
 
             pdf_ax = axs[0]
-            for label, df in box_plot_df.groupby("Source"):
-                sns.distplot(
-                    df[metric],
-                    bins=50,
-                    norm_hist=True,
-                    label=label,
-                    ax=pdf_ax,
-                    color=palette[label],
-                )
+            sns.histplot(
+                data=box_plot_df,
+                x=metric,
+                bins=50,
+                stat="probability",
+                common_norm=False,
+                kde=True,
+                hue="Source",
+                palette=palette,
+                ax=pdf_ax,
+                legend=True,
+            )
 
-            pdf_ax.legend()
             pdf_ax.set_title(metric)
             pdf_ax.set_xlim(xlim)
             pdf_ax.set_xlabel("")
