@@ -9,7 +9,9 @@ import os
 import os.path
 import tempfile
 
+import click
 import pandas as pd
+from botocore.exceptions import ClientError
 from scmdata.run import ScmRun, run_append
 
 LOGGER = logging.getLogger(__name__)
@@ -168,3 +170,17 @@ def temporary_file_to_upload(df, max_size=1024, compress=False):
         yield buffer
     finally:
         buffer.close()
+
+
+def _upload_file(client, bucket, key, run, compress=True):
+    # Small files are kept in memory while bigger files are written to disk and automatically cleaned up
+    LOGGER.info("Preparing {} for upload".format(key))
+    with temporary_file_to_upload(run, max_size=1024, compress=compress) as fh:
+        try:
+            if compress:
+                key += ".gz"
+            LOGGER.info("Uploading {}".format(key))
+            client.upload_fileobj(fh, Bucket=bucket, Key=key)
+        except ClientError:  # pragma: no cover
+            LOGGER.exception("Failed to upload file")
+            raise click.ClickException("Failed to upload file")
